@@ -57,6 +57,8 @@ module Mongo
     # Delegate to the cluster for the next primary.
     def_delegators :cluster, :next_primary
 
+    def_delegators :client, :tracer
+
     # Options that can be updated on a new Collection instance via the #with method.
     #
     # @since 2.1.0
@@ -410,21 +412,24 @@ module Mongo
           client: client,
           session: session
         )
-        maybe_create_qe_collections(opts[:encrypted_fields], client, session) do |encrypted_fields|
-          Operation::Create.new(
-            selector: operation,
-            db_name: database.name,
-            write_concern: write_concern,
-            session: session,
-            # Note that these are collection options, collation isn't
-            # taken from options passed to the create method.
-            collation: options[:collation] || options['collation'],
-            encrypted_fields: encrypted_fields,
-            validator: options[:validator],
-          ).execute(
-            next_primary(nil, session),
-            context: context
-          )
+        operation = Operation::Create.new(
+          selector: operation,
+          db_name: database.name,
+          write_concern: write_concern,
+          session: session,
+          # Note that these are collection options, collation isn't
+          # taken from options passed to the create method.
+          collation: options[:collation] || options['collation'],
+          validator: options[:validator],
+        )
+        tracer.trace_operation(operation, context, op_name: 'createCollection') do
+          maybe_create_qe_collections(opts[:encrypted_fields], client, session) do |encrypted_fields|
+            operation.encrypted_fields = encrypted_fields
+            operation.execute(
+              next_primary(nil, session),
+              context: context
+            )
+          end
         end
       end
     end
@@ -453,25 +458,27 @@ module Mongo
     # @since 2.0.0
     def drop(opts = {})
       client.with_session(opts) do |session|
-        maybe_drop_emm_collections(opts[:encrypted_fields], client, session) do
-          temp_write_concern = write_concern
-          write_concern = if opts[:write_concern]
-            WriteConcern.get(opts[:write_concern])
-          else
-            temp_write_concern
+        context = Operation::Context.new(
+          client: client,
+          session: session,
+          operation_timeouts: operation_timeouts(opts)
+        )
+        temp_write_concern = write_concern
+        write_concern = if opts[:write_concern]
+                          WriteConcern.get(opts[:write_concern])
+                        else
+                          temp_write_concern
+                        end
+        operation = Operation::Drop.new({
+          selector: { :drop => name },
+          db_name: database.name,
+          write_concern: write_concern,
+          session: session,
+        })
+        tracer.trace_operation(operation, context, op_name: 'dropCollection') do
+          maybe_drop_emm_collections(opts[:encrypted_fields], client, session) do
+            do_drop(operation, session, context)
           end
-          context = Operation::Context.new(
-            client: client,
-            session: session,
-            operation_timeouts: operation_timeouts(opts)
-          )
-          operation = Operation::Drop.new({
-            selector: { :drop => name },
-            db_name: database.name,
-            write_concern: write_concern,
-            session: session,
-          })
-          do_drop(operation, session, context)
         end
       end
     end
@@ -865,19 +872,22 @@ module Mongo
           session: session,
           operation_timeouts: operation_timeouts(opts)
           )
-        write_with_retry(write_concern, context: context) do |connection, txn_num, context|
-          Operation::Insert.new(
-            :documents => [ document ],
-            :db_name => database.name,
-            :coll_name => name,
-            :write_concern => write_concern,
-            :bypass_document_validation => !!opts[:bypass_document_validation],
-            :options => opts,
-            :id_generator => client.options[:id_generator],
-            :session => session,
-            :txn_num => txn_num,
-            :comment => opts[:comment]
-          ).execute_with_connection(connection, context: context)
+        operation = Operation::Insert.new(
+              :documents => [ document ],
+              :db_name => database.name,
+              :coll_name => name,
+              :write_concern => write_concern,
+              :bypass_document_validation => !!opts[:bypass_document_validation],
+              :options => opts,
+              :id_generator => client.options[:id_generator],
+              :session => session,
+              :comment => opts[:comment]
+            )
+        tracer.trace_operation(operation, context) do
+          write_with_retry(write_concern, context: context) do |connection, txn_num, context|
+            operation.txn_num = txn_num
+            operation.execute_with_connection(connection, context: context)
+          end
         end
       end
     end
@@ -1049,6 +1059,11 @@ module Mongo
     #   May be specified as a Hash (e.g. { _id: 1 }) or a String (e.g. "_id_").
     # @option options [ Hash ] :let Mapping of variables to use in the command.
     #   See the server documentation for details.
+    # @option options [ Hash ] :sort Specifies which document the operation
+    #   replaces if the query matches multiple documents. The first document
+    #   matched by the sort order will be replaced.
+    #   This option is only supported by servers >= 8.0. Older servers will
+    #   report an error for using this option.
     #
     # @return [ Result ] The response from the database.
     #
@@ -1115,6 +1130,11 @@ module Mongo
     #   May be specified as a Hash (e.g. { _id: 1 }) or a String (e.g. "_id_").
     # @option options [ Hash ] :let Mapping of variables to use in the command.
     #   See the server documentation for details.
+    # @option options [ Hash ] :sort Specifies which document the operation
+    #   updates if the query matches multiple documents. The first document
+    #   matched by the sort order will be updated.
+    #   This option is only supported by servers >= 8.0. Older servers will
+    #   report an error for using this option.
     #
     # @return [ Result ] The response from the database.
     #
