@@ -211,22 +211,24 @@ module Mongo
               session: session,
               operation_timeouts: operation_timeouts(opts)
             )
-            write_with_retry(write_concern, context: context) do |connection, txn_num, context|
-              gte_4_4 = connection.server.description.server_version_gte?('4.4')
-              if !gte_4_4 && opts[:hint] && write_concern && !write_concern.acknowledged?
-                raise Error::UnsupportedOption.hint_error(unacknowledged_write: true)
+            operation = Operation::WriteCommand.new(
+              selector: cmd,
+              db_name: database.name,
+              write_concern: write_concern,
+              session: session,
+            )
+            value = tracer.trace_operation(operation, context, op_name: 'findOneAndUpdate') do
+              write_with_retry(write_concern, context: context) do |connection, txn_num, context|
+                gte_4_4 = connection.server.description.server_version_gte?('4.4')
+                if !gte_4_4 && opts[:hint] && write_concern && !write_concern.acknowledged?
+                  raise Error::UnsupportedOption.hint_error(unacknowledged_write: true)
+                end
+                operation.txn_num = txn_num
+                operation.execute_with_connection(connection, context: context)
               end
-
-              Operation::WriteCommand.new(
-                selector: cmd,
-                db_name: database.name,
-                write_concern: write_concern,
-                session: session,
-                txn_num: txn_num,
-              ).execute_with_connection(connection, context: context)
-            end
-          end.first&.fetch('value', nil)
-          value unless value.nil? || value.empty?
+            end.first&.fetch('value', nil)
+            value unless value.nil? || value.empty?
+          end
         end
 
         # Remove documents from the collection.
@@ -275,22 +277,24 @@ module Mongo
               session: session,
               operation_timeouts: operation_timeouts(opts)
             )
-            nro_write_with_retry(write_concern, context: context) do |connection, txn_num, context|
-              gte_4_4 = connection.server.description.server_version_gte?('4.4')
-              if !gte_4_4 && opts[:hint] && write_concern && !write_concern.acknowledged?
-                raise Error::UnsupportedOption.hint_error(unacknowledged_write: true)
+            operation = Operation::Delete.new(
+              deletes: [ delete_doc ],
+              db_name: collection.database.name,
+              coll_name: collection.name,
+              write_concern: write_concern,
+              bypass_document_validation: !!opts[:bypass_document_validation],
+              session: session,
+              let: opts[:let],
+              comment: opts[:comment],
+            )
+            tracer.trace_operation(operation, context, op_name: 'deleteMany') do
+              nro_write_with_retry(write_concern, context: context) do |connection, txn_num, context|
+                gte_4_4 = connection.server.description.server_version_gte?('4.4')
+                if !gte_4_4 && opts[:hint] && write_concern && !write_concern.acknowledged?
+                  raise Error::UnsupportedOption.hint_error(unacknowledged_write: true)
+                end
+                operation.execute_with_connection(connection, context: context)
               end
-
-              Operation::Delete.new(
-                deletes: [ delete_doc ],
-                db_name: collection.database.name,
-                coll_name: collection.name,
-                write_concern: write_concern,
-                bypass_document_validation: !!opts[:bypass_document_validation],
-                session: session,
-                let: opts[:let],
-                comment: opts[:comment],
-              ).execute_with_connection(connection, context: context)
             end
           end
         end
@@ -389,6 +393,11 @@ module Mongo
         # @option opts [ true, false ] :upsert Whether to upsert if the
         #   document doesn't exist.
         #   Can be :w => Integer, :fsync => Boolean, :j => Boolean.
+        # @option opts [ Hash ] :sort Specifies which document the operation
+        #   replaces if the query matches multiple documents. The first document
+        #   matched by the sort order will be replaced.
+        #   This option is only supported by servers >= 8.0. Older servers will
+        #   report an error for using this option.
         #
         # @return [ Result ] The response from the database.
         #
@@ -410,6 +419,7 @@ module Mongo
               Operation::U => replacement,
               hint: opts[:hint],
               collation: opts[:collation] || opts['collation'] || collation,
+              sort: opts[:sort] || opts['sort'],
             }.compact
             if opts[:upsert]
               update_doc['upsert'] = true
@@ -549,6 +559,11 @@ module Mongo
         #   document doesn't exist.
         # @option opts [ Hash ] :write_concern The write concern options.
         #   Can be :w => Integer, :fsync => Boolean, :j => Boolean.
+        # @option opts [ Hash ] :sort Specifies which document the operation
+        #   updates if the query matches multiple documents. The first document
+        #   matched by the sort order will be updated.
+        #   This option is only supported by servers >= 8.0. Older servers will
+        #   report an error for using this option.
         #
         # @return [ Result ] The response from the database.
         #
@@ -570,6 +585,7 @@ module Mongo
               Operation::U => spec,
               hint: opts[:hint],
               collation: opts[:collation] || opts['collation'] || collation,
+              sort: opts[:sort] || opts['sort'],
             }.compact
             if opts[:upsert]
               update_doc['upsert'] = true
@@ -580,23 +596,25 @@ module Mongo
               session: session,
               operation_timeouts: operation_timeouts(opts)
             )
-            write_with_retry(write_concern, context: context) do |connection, txn_num, context|
-              gte_4_2 = connection.server.description.server_version_gte?('4.2')
-              if !gte_4_2 && opts[:hint] && write_concern && !write_concern.acknowledged?
-                raise Error::UnsupportedOption.hint_error(unacknowledged_write: true)
+            operation = Operation::Update.new(
+              updates: [ update_doc ],
+              db_name: collection.database.name,
+              coll_name: collection.name,
+              write_concern: write_concern,
+              bypass_document_validation: !!opts[:bypass_document_validation],
+              session: session,
+              let: opts[:let],
+              comment: opts[:comment],
+            )
+            tracer.trace_operation(operation, context) do
+              write_with_retry(write_concern, context: context) do |connection, txn_num, context|
+                gte_4_2 = connection.server.description.server_version_gte?('4.2')
+                if !gte_4_2 && opts[:hint] && write_concern && !write_concern.acknowledged?
+                  raise Error::UnsupportedOption.hint_error(unacknowledged_write: true)
+                end
+                operation.txn_num = txn_num
+                operation.execute_with_connection(connection, context: context)
               end
-
-              Operation::Update.new(
-                updates: [ update_doc ],
-                db_name: collection.database.name,
-                coll_name: collection.name,
-                write_concern: write_concern,
-                bypass_document_validation: !!opts[:bypass_document_validation],
-                session: session,
-                txn_num: txn_num,
-                let: opts[:let],
-                comment: opts[:comment],
-              ).execute_with_connection(connection, context: context)
             end
           end
         end
