@@ -218,7 +218,8 @@ module Mongo
     # @api private
     def_delegators :cluster,
                    :monitor_app_metadata,
-                   :push_monitor_app_metadata
+                   :push_monitor_app_metadata,
+                   :tracer
 
     def_delegators :features,
                    :check_driver_support!
@@ -616,7 +617,9 @@ module Mongo
         return
       end
 
-      if options[:generation] && options[:generation] < pool&.generation
+      # NOTE: You cannot use safe navigation here because if pool is nil you end
+      # up trying to evaluate Integer < nil which is invalid.
+      if options[:generation] && pool && options[:generation] < pool.generation
         return
       end
 
