@@ -130,6 +130,8 @@ module Mongo
     # @since 2.5.0
     attr_reader :operation_time
 
+    def_delegators :client, :tracer
+
     # Sets the dirty state to the given value for the underlying server
     # session. If there is no server session, this does nothing.
     #
@@ -446,20 +448,14 @@ module Mongo
     #
     # @since 2.7.0
     def with_transaction(options = nil)
-      if timeout_ms = (options || {})[:timeout_ms]
-        timeout_sec = timeout_ms / 1_000.0
-        deadline = Utils.monotonic_time + timeout_sec
-        @with_transaction_deadline = deadline
-      elsif default_timeout_ms = @options[:default_timeout_ms]
-        timeout_sec = default_timeout_ms / 1_000.0
-        deadline = Utils.monotonic_time + timeout_sec
-        @with_transaction_deadline = deadline
-      elsif @client.timeout_sec
-        deadline = Utils.monotonic_time + @client.timeout_sec
-        @with_transaction_deadline = deadline
-      else
-        deadline = Utils.monotonic_time + 120
-      end
+      @with_transaction_deadline = calculate_with_transaction_deadline(options)
+      deadline = if @with_transaction_deadline
+                   # CSOT enabled, so we have a customer defined deadline.
+                   @with_transaction_deadline
+                 else
+                    # CSOT not enabled, so we use the default deadline, 120 seconds.
+                   Utils.monotonic_time + 120
+                 end
       transaction_in_progress = false
       loop do
         commit_options = {}
@@ -478,7 +474,7 @@ module Mongo
             transaction_in_progress = false
           end
 
-          if Utils.monotonic_time >= deadline
+          if deadline_expired?(deadline)
             transaction_in_progress = false
             raise
           end
@@ -500,7 +496,7 @@ module Mongo
             return rv
           rescue Mongo::Error => e
             if e.label?('UnknownTransactionCommitResult')
-              if Utils.monotonic_time >= deadline ||
+              if  deadline_expired?(deadline) ||
                 e.is_a?(Error::OperationFailure::Family) && e.max_time_ms_expired?
               then
                 transaction_in_progress = false
@@ -622,6 +618,7 @@ module Mongo
 
       @state = STARTING_TRANSACTION_STATE
       @already_committed = false
+      tracer.start_transaction_span(self)
 
       # This method has no explicit return value.
       # We could return nil here but true indicates to the user that the
@@ -701,9 +698,14 @@ module Mongo
               txn_num: txn_num,
               write_concern: write_concern,
             }
-            Operation::Command.new(spec).execute_with_connection(connection, context: context)
+            operation = Operation::Command.new(spec)
+            tracer.trace_operation(operation, context, op_name: 'commitTransaction') do
+              operation.execute_with_connection(connection, context: context)
+            end
           end
         end
+        # Finish the transaction span before changing state
+        tracer.finish_transaction_span(self)
       ensure
         @state = TRANSACTION_COMMITTED_STATE
         @committing_transaction = false
@@ -758,24 +760,31 @@ module Mongo
             ending_transaction: true, context: context,
           ) do |connection, txn_num, context|
             begin
-              Operation::Command.new(
+              operation = Operation::Command.new(
                 selector: { abortTransaction: 1 },
                 db_name: 'admin',
                 session: self,
                 txn_num: txn_num
-              ).execute_with_connection(connection, context: context)
+              )
+              tracer.trace_operation(operation, context, op_name: 'abortTransaction') do
+                operation.execute_with_connection(connection, context: context)
+              end
             ensure
               unpin
             end
           end
         end
 
+        # Finish the transaction span before changing state
+        tracer.finish_transaction_span(self)
         @state = TRANSACTION_ABORTED_STATE
       rescue Mongo::Error::InvalidTransactionOperation
         raise
       rescue Mongo::Error
+        tracer.finish_transaction_span(self)
         @state = TRANSACTION_ABORTED_STATE
       rescue Exception
+        tracer.finish_transaction_span(self)
         @state = TRANSACTION_ABORTED_STATE
         raise
       ensure
@@ -1191,6 +1200,8 @@ module Mongo
     # @api private
     attr_accessor :snapshot_timestamp
 
+    # @return [ Integer | nil ] The deadline for the current transaction, if any.
+    # @api private
     attr_reader :with_transaction_deadline
 
     private
@@ -1286,5 +1297,30 @@ module Mongo
         end
       end
     end
+
+    def calculate_with_transaction_deadline(opts)
+      calc = -> (timeout) {
+        if timeout == 0
+          0
+        else
+          Utils.monotonic_time + (timeout / 1000.0)
+        end
+      }
+      if timeout_ms = opts&.dig(:timeout_ms)
+        calc.call(timeout_ms)
+      elsif default_timeout_ms = @options[:default_timeout_ms]
+        calc.call(default_timeout_ms)
+      elsif @client.timeout_ms
+        calc.call(@client.timeout_ms)
+      end
+    end
+
+    def deadline_expired?(deadline)
+      if deadline.zero?
+        false
+      else
+        Utils.monotonic_time >= deadline
+      end
+    end
   end
 end
