@@ -29,7 +29,7 @@ class SpecConfig
         @connect_options = { connect: :direct }
       end
       if @uri_options[:ssl].nil?
-        @ssl = (ENV['SSL'] == 'ssl') || (ENV['SSL_ENABLED'] == 'true')
+        @ssl = (%w(yes ssl).include?(ENV['SSL'])) || (ENV['SSL_ENABLED'] == 'true')
       else
         @ssl = @uri_options[:ssl]
       end
@@ -162,19 +162,9 @@ class SpecConfig
     ENV.key?('OCSP_CONNECTIVITY') && ENV['OCSP_CONNECTIVITY'] != ''
   end
 
-  # Detect whether specs are running against Mongodb Atlas serverless instance.
-  # This method does not do any magic, it just checks whether environment
-  # variable SERVERLESS is set. This is a recommended way to inform spec runners
-  # that they are running against a serverless instance
-  #
-  # @return [ true | false ] Whether specs are running against a serverless instance.
-  def serverless?
-    !!ENV['SERVERLESS']
-  end
-
   def kill_all_server_sessions?
-    !serverless? && # Serverless instances do not support killAllSessions command.
-      ClusterConfig.instance.fcv_ish >= '3.6'
+    allow = ENV['KILL_ALL_SERVER_SESSIONS'] != '0'
+    allow && ClusterConfig.instance.fcv_ish >= '3.6'
   end
 
   # Test suite configuration
@@ -276,34 +266,72 @@ EOT
     Pathname.new("#{spec_root}/support/certificates")
   end
 
+  def evergreen_certs_dir
+    Pathname.new("#{spec_root}/../.evergreen/x509gen")
+  end
+
   def ocsp_files_dir
     Pathname.new("#{spec_root}/../.mod/drivers-evergreen-tools/.evergreen/ocsp")
   end
 
-  # TLS certificates & keys
+  # Evergreen cert paths
 
-  def local_client_key_path
-    "#{ssl_certs_dir}/client.key"
+  def evergreen_ca_pem_path
+    "#{evergreen_certs_dir}/ca.pem"
+  end
+
+  def evergreen_client_pem_path
+    "#{evergreen_certs_dir}/client.pem"
+  end
+
+  def evergreen_client_key_path
+    "#{evergreen_certs_dir}/client-private.pem"
+  end
+
+  def evergreen_client_cert_path
+    "#{evergreen_certs_dir}/client-public.pem"
+  end
+
+  def ca_cert_path
+    if drivers_tools?
+      evergreen_ca_pem_path
+    else
+      local_ca_cert_path
+    end
+  end
+
+  def client_cert_path
+    if drivers_tools?
+      evergreen_client_pem_path
+    else
+      local_client_cert_path
+    end
   end
 
   def client_key_path
-    if drivers_tools? && ENV['DRIVER_TOOLS_CLIENT_KEY_PEM']
-      ENV['DRIVER_TOOLS_CLIENT_KEY_PEM']
+    if drivers_tools?
+      evergreen_client_key_path
     else
       local_client_key_path
     end
   end
 
-  def local_client_cert_path
-    "#{ssl_certs_dir}/client.crt"
+  def client_pem_path
+    if drivers_tools?
+      evergreen_client_pem_path
+    else
+      local_client_pem_path
+    end
   end
 
-  def client_cert_path
-    if drivers_tools? && ENV['DRIVER_TOOLS_CLIENT_CERT_PEM']
-      ENV['DRIVER_TOOLS_CLIENT_CERT_PEM']
-    else
-      local_client_cert_path
-    end
+  # Local TLS certificates & keys
+
+  def local_client_key_path
+    "#{ssl_certs_dir}/client.key"
+  end
+
+  def local_client_cert_path
+    "#{ssl_certs_dir}/client.crt"
   end
 
   def local_client_pem_path
@@ -314,14 +342,6 @@ EOT
     end
   end
 
-  def client_pem_path
-    if drivers_tools? && ENV['DRIVER_TOOLS_CLIENT_CERT_KEY_PEM']
-      ENV['DRIVER_TOOLS_CLIENT_CERT_KEY_PEM']
-    else
-      local_client_pem_path
-    end
-  end
-
   def client_x509_pem_path
     "#{ssl_certs_dir}/client-x509.pem"
   end
@@ -358,14 +378,6 @@ EOT
     "#{ssl_certs_dir}/ca.crt"
   end
 
-  def ca_cert_path
-    if drivers_tools? && ENV['DRIVER_TOOLS_CA_PEM']
-      ENV['DRIVER_TOOLS_CA_PEM']
-    else
-      local_ca_cert_path
-    end
-  end
-
   def multi_ca_path
     "#{ssl_certs_dir}/multi-ca.crt"
   end
@@ -670,10 +682,6 @@ EOT
 
   # Get the default test user for the suite on versions 2.6 and higher.
   def test_user
-    # When testing against a serverless instance, we are not allowed to create
-    # new users, we just have one user for everyhing.
-    return root_user if serverless?
-
     Mongo::Auth::User.new(
       database: 'admin',
       user: 'ruby-test-user',
@@ -764,4 +772,14 @@ EOT
   def single_mongos?
     %w(1 true yes).include?(ENV['SINGLE_MONGOS'])
   end
+
+  # serverless is deprecated, but it still gets called from some places
+  # (see Mrss::Constraints), etc.
+  module DeprecatedServerless
+    def serverless?
+      false
+    end
+  end
+
+  prepend DeprecatedServerless
 end
